Demo
====

| An example app utilising ``django-trench`` is available live on `django-trench.herokuapp.com`_

.. note:: To check simple functionalities of live demo use ``demo`` user and password ``trenchdemo``. That account has email authentication activated, so check this `virtual mailbox`_ to get code.

| Demo app can be run locally straight from the source code. Check out :doc:`examples`.
| App can be easily deployed to `Heroku`_ with single command. Checkout ``demo`` branch.

.. _django-trench.herokuapp.com: http://django-trench.herokuapp.com
.. _virtual mailbox: https://mailsac.com/inbox/trench@mailsac.com
.. _Heroku: https://devcenter.heroku.com/articles/build-docker-images-heroku-yml#getting-started
